;; Generated package description from boxy-headings.el  -*- no-byte-compile: t -*-
(define-package "boxy-headings" "2.1.5.0.20240503.172743" "View org files in a boxy diagram" '((emacs "26.1") (boxy "1.1") (org "9.4")) :commit "15f54ab24bd396cc5b73f33018f7d873fa30eb04" :authors '(("Amy Grinn" . "grinn.amy@gmail.com")) :maintainer '("Amy Grinn" . "grinn.amy@gmail.com") :keywords '("tools") :url "https://gitlab.com/grinn.amy/boxy-headings")
